@@ -1,5 +1,6 @@
 from __future__ import unicode_literals
 from django.core.files.uploadedfile import InMemoryUploadedFile
+from django.db.models.fields.files import FieldFile
 from django.utils.encoding import python_2_unicode_compatible
 from django.contrib.staticfiles.storage import staticfiles_storage
 
@@ -15,7 +16,13 @@ class BaseTag(object):
     meta_content = ""
     tag_value = ""
 
-    def __init__(self, tag_name=None, self_closed=None, meta_name=None, meta_content=None, tag_value=None):
+    def __init__(
+            self,
+            tag_name=None,
+            self_closed=None,
+            meta_name=None,
+            meta_content=None,
+            tag_value=None):
         """
         Explicit Initialization of Tag
         :param tag_name:
@@ -160,9 +167,15 @@ class ImageMetaTag(BaseMetatag):
                     self._inmemoryuploadedfile = None
                     rel_path = kwargs['value']
                 if staticfiles_storage:
-                    self.meta_content = staticfiles_storage.url(rel_path)
+                    if isinstance(rel_path, FieldFile):
+                        self.meta_content = staticfiles_storage.url(rel_path.name)
+                    else:
+                        self.meta_content = rel_path
                 else:
-                    self.meta_content = rel_path
+                    if isinstance(rel_path, FieldFile):
+                        self.meta_content = rel_path.name
+                    else:
+                        self.meta_content = rel_path
 
     @property
     def url(self):
